pub struct BlockMeta {
pub prepared: bool,
pub codes_queue: Option<VecDeque<CodeId>>,
pub last_committed_batch: Option<Digest>,
pub last_committed_mb: Option<H256>,
pub last_committed_eb: Option<H256>,
pub latest_era_validators_committed: Option<u64>,
}Expand description
Ethexe metadata associated with an on-chain block.
Fields
prepared: boolBlock has been prepared, meaning: all metadata is ready, all predecessors till start block are prepared too.
codes_queue: Option<VecDeque<CodeId>>Queue of code ids waiting for validation status commitment on-chain.
last_committed_batch: Option<Digest>Last committed on-chain batch hash (digest).
last_committed_mb: Option<H256>Last committed MB hash.
last_committed_eb: Option<H256>Last committed EB hash.
latest_era_validators_committed: Option<u64>Latest era with committed validators.