BlockMetaStorageRW

Trait BlockMetaStorageRW 

pub trait BlockMetaStorageRW: BlockMetaStorageRO {
    // Required method
    fn mutate_block_meta(
        &self,
        block_hash: H256,
        f: impl FnOnce(&mut BlockMeta),
    );
}

Required Methods

fn mutate_block_meta(&self, block_hash: H256, f: impl FnOnce(&mut BlockMeta))

NOTE: if BlockMeta doesn’t exist in the database, it will be created with default values and then will be mutated.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, T: 'a + BlockMetaStorageRW + ?Sized> BlockMetaStorageRW for &'a T

Source

fn mutate_block_meta(&self, block_hash: H256, f: impl FnOnce(&mut BlockMeta))

Implementors