pub struct Signature(/* private fields */);Expand description
A recoverable ECDSA signature.
Implementations
Sourceimpl Signature
impl Signature
Sourcepub fn create<T>(
private_key: &PrivateKey,
data: T,
) -> Result<Signature, SignerError>
pub fn create<T>( private_key: &PrivateKey, data: T, ) -> Result<Signature, SignerError>
Create a recoverable signature for the provided data using the private key.
Sourcepub fn create_from_digest(
private_key: &PrivateKey,
digest: Digest,
) -> Result<Signature, SignerError>
pub fn create_from_digest( private_key: &PrivateKey, digest: Digest, ) -> Result<Signature, SignerError>
Create a recoverable signature from a precomputed digest.
Sourcepub fn create_message<T>(
private_key: &PrivateKey,
data: T,
) -> Result<Signature, SignerError>
pub fn create_message<T>( private_key: &PrivateKey, data: T, ) -> Result<Signature, SignerError>
Create a recoverable signature for the provided digest using the private key according to EIP-191.
Sourcepub fn recover<T>(&self, data: T) -> Result<PublicKey, SignerError>
pub fn recover<T>(&self, data: T) -> Result<PublicKey, SignerError>
Recovers the public key which was used to create the signature for the signed data.
Sourcepub fn recover_from_digest(
&self,
digest: &Digest,
) -> Result<PublicKey, SignerError>
pub fn recover_from_digest( &self, digest: &Digest, ) -> Result<PublicKey, SignerError>
Recovers the public key using a precomputed digest.
Sourcepub fn recover_message<T>(&self, data: T) -> Result<PublicKey, SignerError>
pub fn recover_message<T>(&self, data: T) -> Result<PublicKey, SignerError>
Recovers public key which was used to create the signature for the signed message according to EIP-191 standard.
Sourcepub fn verify<T>(
&self,
public_key: PublicKey,
data: T,
) -> Result<(), SignerError>
pub fn verify<T>( &self, public_key: PublicKey, data: T, ) -> Result<(), SignerError>
Verifies the signature using the public key and data.
Sourcepub fn verify_with_digest(
&self,
public_key: PublicKey,
digest: &Digest,
) -> Result<(), SignerError>
pub fn verify_with_digest( &self, public_key: PublicKey, digest: &Digest, ) -> Result<(), SignerError>
Verifies the signature against a precomputed digest.
Sourcepub fn verify_message<T>(
&self,
public_key: PublicKey,
data: T,
) -> Result<(), SignerError>
pub fn verify_message<T>( &self, public_key: PublicKey, data: T, ) -> Result<(), SignerError>
Verifies message using Self::verify method according to EIP-191 standard.
Sourcepub fn validate<T>(&self, data: T) -> Result<PublicKey, SignerError>
pub fn validate<T>(&self, data: T) -> Result<PublicKey, SignerError>
Signature validation with recovery.
Sourcepub fn validate_message<T>(&self, data: T) -> Result<PublicKey, SignerError>
pub fn validate_message<T>(&self, data: T) -> Result<PublicKey, SignerError>
Signature validation: verify the signature with public key recovery from the signature of the message signed according to EIP-191 standard.
Sourcepub fn from_pre_eip155_bytes(bytes: [u8; 65]) -> Option<Signature>
pub fn from_pre_eip155_bytes(bytes: [u8; 65]) -> Option<Signature>
Creates a signature from the bytes in the pre-EIP-155 format (V in {27, 28}).
Sourcepub fn into_pre_eip155_bytes(self) -> [u8; 65]
pub fn into_pre_eip155_bytes(self) -> [u8; 65]
Convert signature into the pre-EIP-155 encoded bytes (V in {27, 28}).
Sourcepub fn as_raw_bytes(&self) -> [u8; 65]
pub fn as_raw_bytes(&self) -> [u8; 65]
Returns internal signature bytes with raw recovery id.
Sourcepub fn into_parts(self) -> (Signature<Secp256k1>, RecoveryId)
pub fn into_parts(self) -> (Signature<Secp256k1>, RecoveryId)
Return the inner signature and recovery id as k256 primitives.