pub struct SignedMessage<T> { /* private fields */ }Expand description
A signed according to EIP-191 message,that contains the data and its signature. Always valid after construction.
Implementations
Sourceimpl<T> SignedMessage<T>
impl<T> SignedMessage<T>
Sourceimpl<T> SignedMessage<T>
impl<T> SignedMessage<T>
pub fn into_verified(self) -> VerifiedData<T>
Sourceimpl<T> SignedMessage<T>
impl<T> SignedMessage<T>
pub fn create( private_key: PrivateKey, data: T, ) -> Result<SignedMessage<T>, SignerError>
pub fn try_from_parts( data: T, signature: Signature, address: Address, ) -> Result<SignedMessage<T>, &'static str>
Sourcepub unsafe fn from_parts_unchecked(
data: T,
signature: Signature,
address: Address,
) -> SignedMessage<T>
pub unsafe fn from_parts_unchecked( data: T, signature: Signature, address: Address, ) -> SignedMessage<T>
The unsafe constructor for SignedMessage.
It is useful to optimize the constructing signed wrappers for types
with the same ToDigest implementation.
Safety
Safety only in cases when you are sure when hashes are equal.