pub enum PromiseEmissionMode {
AlwaysEmit,
ConsensusDriven,
}Expand description
The PromiseEmissionMode configures the promise emission mode for the ethexe node
Variants
AlwaysEmit
Node should always emit promises during MB execution.
Always set PromisePolicy::Enabled.
ConsensusDriven
PromisePolicy is decided per-MB by the consensus / compute layer.
Implementations
Sourceimpl PromiseEmissionMode
impl PromiseEmissionMode
Sourcepub const fn is_always_emit(&self) -> bool
pub const fn is_always_emit(&self) -> bool
Returns true if this value is of type AlwaysEmit. Returns false otherwise
Sourcepub const fn is_consensus_driven(&self) -> bool
pub const fn is_consensus_driven(&self) -> bool
Returns true if this value is of type ConsensusDriven. Returns false otherwise