pub enum PromisePolicy {
Enabled,
Disabled,
}Expand description
PromisePolicy tells processor whether should it emits promises or not.
Variants
Implementations
Sourceimpl PromisePolicy
impl PromisePolicy
Sourcepub const fn is_enabled(&self) -> bool
pub const fn is_enabled(&self) -> bool
Returns true if this value is of type Enabled. Returns false otherwise
Sourcepub const fn is_disabled(&self) -> bool
pub const fn is_disabled(&self) -> bool
Returns true if this value is of type Disabled. Returns false otherwise