pub struct MessageEvent {
pub id: MessageId,
pub destination: ActorId,
pub payload: Vec<u8>,
pub value: u128,
}Fields
id: MessageIddestination: ActorIdpayload: Vec<u8>value: u128Trait Implementations
Sourceimpl Clone for MessageEvent
impl Clone for MessageEvent
Sourcefn clone(&self) -> MessageEvent
fn clone(&self) -> MessageEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MessageEvent
impl Debug for MessageEvent
Sourceimpl Decode for MessageEvent
impl Decode for MessageEvent
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for MessageEvent
impl Encode for MessageEvent
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for MessageEvent
impl Eq for MessageEvent
Sourceimpl Hash for MessageEvent
impl Hash for MessageEvent
Sourceimpl PartialEq for MessageEvent
impl PartialEq for MessageEvent
Sourcefn eq(&self, other: &MessageEvent) -> bool
fn eq(&self, other: &MessageEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MessageEvent