pub struct OwnedBalanceTopUpRequestedEvent {
pub value: u128,
}Fields
value: u128Trait Implementations
Sourceimpl Clone for OwnedBalanceTopUpRequestedEvent
impl Clone for OwnedBalanceTopUpRequestedEvent
Sourcefn clone(&self) -> OwnedBalanceTopUpRequestedEvent
fn clone(&self) -> OwnedBalanceTopUpRequestedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Decode for OwnedBalanceTopUpRequestedEvent
impl Decode for OwnedBalanceTopUpRequestedEvent
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de> Deserialize<'de> for OwnedBalanceTopUpRequestedEvent
impl<'de> Deserialize<'de> for OwnedBalanceTopUpRequestedEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for OwnedBalanceTopUpRequestedEvent
impl Encode for OwnedBalanceTopUpRequestedEvent
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>(
&self,
f: __CodecUsingEncodedCallback,
) -> __CodecOutputReturn
fn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>( &self, f: __CodecUsingEncodedCallback, ) -> __CodecOutputReturn
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for OwnedBalanceTopUpRequestedEvent
impl Eq for OwnedBalanceTopUpRequestedEvent
Sourceimpl PartialEq for OwnedBalanceTopUpRequestedEvent
impl PartialEq for OwnedBalanceTopUpRequestedEvent
Sourcefn eq(&self, other: &OwnedBalanceTopUpRequestedEvent) -> bool
fn eq(&self, other: &OwnedBalanceTopUpRequestedEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for OwnedBalanceTopUpRequestedEvent