pub struct ReplyEvent {
pub payload: Vec<u8>,
pub value: u128,
pub reply_to: MessageId,
pub reply_code: ReplyCode,
}Fields
payload: Vec<u8>value: u128reply_to: MessageIdreply_code: ReplyCodeTrait Implementations
Sourceimpl Clone for ReplyEvent
impl Clone for ReplyEvent
Sourcefn clone(&self) -> ReplyEvent
fn clone(&self) -> ReplyEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReplyEvent
impl Debug for ReplyEvent
Sourceimpl Decode for ReplyEvent
impl Decode for ReplyEvent
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for ReplyEvent
impl Encode for ReplyEvent
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for ReplyEvent
impl Eq for ReplyEvent
Sourceimpl Hash for ReplyEvent
impl Hash for ReplyEvent
Sourceimpl PartialEq for ReplyEvent
impl PartialEq for ReplyEvent
Sourcefn eq(&self, other: &ReplyEvent) -> bool
fn eq(&self, other: &ReplyEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ReplyEvent