pub struct ReplyQueueingRequestedEvent {
pub replied_to: MessageId,
pub source: ActorId,
pub payload: Vec<u8>,
pub value: u128,
}Fields
replied_to: MessageIdsource: ActorIdpayload: Vec<u8>value: u128Trait Implementations
Sourceimpl Clone for ReplyQueueingRequestedEvent
impl Clone for ReplyQueueingRequestedEvent
Sourcefn clone(&self) -> ReplyQueueingRequestedEvent
fn clone(&self) -> ReplyQueueingRequestedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReplyQueueingRequestedEvent
impl Debug for ReplyQueueingRequestedEvent
Sourceimpl Decode for ReplyQueueingRequestedEvent
impl Decode for ReplyQueueingRequestedEvent
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de> Deserialize<'de> for ReplyQueueingRequestedEvent
impl<'de> Deserialize<'de> for ReplyQueueingRequestedEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for ReplyQueueingRequestedEvent
impl Encode for ReplyQueueingRequestedEvent
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for ReplyQueueingRequestedEvent
impl Eq for ReplyQueueingRequestedEvent
Sourceimpl Hash for ReplyQueueingRequestedEvent
impl Hash for ReplyQueueingRequestedEvent
Sourceimpl PartialEq for ReplyQueueingRequestedEvent
impl PartialEq for ReplyQueueingRequestedEvent
Sourcefn eq(&self, other: &ReplyQueueingRequestedEvent) -> bool
fn eq(&self, other: &ReplyQueueingRequestedEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ReplyQueueingRequestedEvent