pub struct StateChangedEvent {
pub state_hash: H256,
}Fields
state_hash: H256Trait Implementations
Sourceimpl Clone for StateChangedEvent
impl Clone for StateChangedEvent
Sourcefn clone(&self) -> StateChangedEvent
fn clone(&self) -> StateChangedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StateChangedEvent
impl Debug for StateChangedEvent
Sourceimpl Decode for StateChangedEvent
impl Decode for StateChangedEvent
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for StateChangedEvent
impl Encode for StateChangedEvent
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>(
&self,
f: __CodecUsingEncodedCallback,
) -> __CodecOutputReturn
fn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>( &self, f: __CodecUsingEncodedCallback, ) -> __CodecOutputReturn
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for StateChangedEvent
impl Eq for StateChangedEvent
Sourceimpl Hash for StateChangedEvent
impl Hash for StateChangedEvent
Sourceimpl PartialEq for StateChangedEvent
impl PartialEq for StateChangedEvent
Sourcefn eq(&self, other: &StateChangedEvent) -> bool
fn eq(&self, other: &StateChangedEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for StateChangedEvent