pub struct BatchCommittedEvent {
pub digest: Digest,
}Fields
digest: DigestTrait Implementations
Sourceimpl Clone for BatchCommittedEvent
impl Clone for BatchCommittedEvent
Sourcefn clone(&self) -> BatchCommittedEvent
fn clone(&self) -> BatchCommittedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BatchCommittedEvent
impl Debug for BatchCommittedEvent
Sourceimpl Decode for BatchCommittedEvent
impl Decode for BatchCommittedEvent
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for BatchCommittedEvent
impl Encode for BatchCommittedEvent
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>(
&self,
f: __CodecUsingEncodedCallback,
) -> __CodecOutputReturn
fn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>( &self, f: __CodecUsingEncodedCallback, ) -> __CodecOutputReturn
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for BatchCommittedEvent
impl Eq for BatchCommittedEvent
Sourceimpl Hash for BatchCommittedEvent
impl Hash for BatchCommittedEvent
Sourceimpl Ord for BatchCommittedEvent
impl Ord for BatchCommittedEvent
Sourcefn cmp(&self, other: &BatchCommittedEvent) -> Ordering
fn cmp(&self, other: &BatchCommittedEvent) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BatchCommittedEvent
impl PartialEq for BatchCommittedEvent
Sourcefn eq(&self, other: &BatchCommittedEvent) -> bool
fn eq(&self, other: &BatchCommittedEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BatchCommittedEvent
impl PartialOrd for BatchCommittedEvent
impl StructuralPartialEq for BatchCommittedEvent