pub struct CodeGotValidatedEvent {
pub code_id: CodeId,
pub valid: bool,
}Fields
code_id: CodeIdvalid: boolTrait Implementations
Sourceimpl Clone for CodeGotValidatedEvent
impl Clone for CodeGotValidatedEvent
Sourcefn clone(&self) -> CodeGotValidatedEvent
fn clone(&self) -> CodeGotValidatedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CodeGotValidatedEvent
impl Debug for CodeGotValidatedEvent
Sourceimpl Decode for CodeGotValidatedEvent
impl Decode for CodeGotValidatedEvent
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for CodeGotValidatedEvent
impl Encode for CodeGotValidatedEvent
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for CodeGotValidatedEvent
impl Eq for CodeGotValidatedEvent
Sourceimpl Hash for CodeGotValidatedEvent
impl Hash for CodeGotValidatedEvent
Sourceimpl Ord for CodeGotValidatedEvent
impl Ord for CodeGotValidatedEvent
Sourcefn cmp(&self, other: &CodeGotValidatedEvent) -> Ordering
fn cmp(&self, other: &CodeGotValidatedEvent) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CodeGotValidatedEvent
impl PartialEq for CodeGotValidatedEvent
Sourcefn eq(&self, other: &CodeGotValidatedEvent) -> bool
fn eq(&self, other: &CodeGotValidatedEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for CodeGotValidatedEvent
impl PartialOrd for CodeGotValidatedEvent
impl StructuralPartialEq for CodeGotValidatedEvent