pub struct CodeValidationRequestedEvent {
pub code_id: CodeId,
pub timestamp: u64,
pub tx_hash: H256,
}Fields
code_id: CodeIdtimestamp: u64tx_hash: H256Trait Implementations
Sourceimpl Clone for CodeValidationRequestedEvent
impl Clone for CodeValidationRequestedEvent
Sourcefn clone(&self) -> CodeValidationRequestedEvent
fn clone(&self) -> CodeValidationRequestedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CodeValidationRequestedEvent
impl Debug for CodeValidationRequestedEvent
Sourceimpl Decode for CodeValidationRequestedEvent
impl Decode for CodeValidationRequestedEvent
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de> Deserialize<'de> for CodeValidationRequestedEvent
impl<'de> Deserialize<'de> for CodeValidationRequestedEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for CodeValidationRequestedEvent
impl Encode for CodeValidationRequestedEvent
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for CodeValidationRequestedEvent
impl Eq for CodeValidationRequestedEvent
Sourceimpl Hash for CodeValidationRequestedEvent
impl Hash for CodeValidationRequestedEvent
Sourceimpl Ord for CodeValidationRequestedEvent
impl Ord for CodeValidationRequestedEvent
Sourcefn cmp(&self, other: &CodeValidationRequestedEvent) -> Ordering
fn cmp(&self, other: &CodeValidationRequestedEvent) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CodeValidationRequestedEvent
impl PartialEq for CodeValidationRequestedEvent
Sourcefn eq(&self, other: &CodeValidationRequestedEvent) -> bool
fn eq(&self, other: &CodeValidationRequestedEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for CodeValidationRequestedEvent
impl PartialOrd for CodeValidationRequestedEvent
impl StructuralPartialEq for CodeValidationRequestedEvent