pub struct ProgramCreatedEvent {
pub actor_id: ActorId,
pub code_id: CodeId,
}Fields
actor_id: ActorIdcode_id: CodeIdTrait Implementations
Sourceimpl Clone for ProgramCreatedEvent
impl Clone for ProgramCreatedEvent
Sourcefn clone(&self) -> ProgramCreatedEvent
fn clone(&self) -> ProgramCreatedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProgramCreatedEvent
impl Debug for ProgramCreatedEvent
Sourceimpl Decode for ProgramCreatedEvent
impl Decode for ProgramCreatedEvent
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de> Deserialize<'de> for ProgramCreatedEvent
impl<'de> Deserialize<'de> for ProgramCreatedEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for ProgramCreatedEvent
impl Encode for ProgramCreatedEvent
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for ProgramCreatedEvent
impl Eq for ProgramCreatedEvent
Sourceimpl Hash for ProgramCreatedEvent
impl Hash for ProgramCreatedEvent
Sourceimpl Ord for ProgramCreatedEvent
impl Ord for ProgramCreatedEvent
Sourcefn cmp(&self, other: &ProgramCreatedEvent) -> Ordering
fn cmp(&self, other: &ProgramCreatedEvent) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ProgramCreatedEvent
impl PartialEq for ProgramCreatedEvent
Sourcefn eq(&self, other: &ProgramCreatedEvent) -> bool
fn eq(&self, other: &ProgramCreatedEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ProgramCreatedEvent
impl PartialOrd for ProgramCreatedEvent
Sourceimpl Serialize for ProgramCreatedEvent
impl Serialize for ProgramCreatedEvent
impl StructuralPartialEq for ProgramCreatedEvent