pub struct StorageSlotChangedEvent {
pub slot: H256,
}Fields
slot: H256Trait Implementations
Sourceimpl Clone for StorageSlotChangedEvent
impl Clone for StorageSlotChangedEvent
Sourcefn clone(&self) -> StorageSlotChangedEvent
fn clone(&self) -> StorageSlotChangedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StorageSlotChangedEvent
impl Debug for StorageSlotChangedEvent
Sourceimpl Decode for StorageSlotChangedEvent
impl Decode for StorageSlotChangedEvent
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de> Deserialize<'de> for StorageSlotChangedEvent
impl<'de> Deserialize<'de> for StorageSlotChangedEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for StorageSlotChangedEvent
impl Encode for StorageSlotChangedEvent
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>(
&self,
f: __CodecUsingEncodedCallback,
) -> __CodecOutputReturn
fn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>( &self, f: __CodecUsingEncodedCallback, ) -> __CodecOutputReturn
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for StorageSlotChangedEvent
impl Eq for StorageSlotChangedEvent
Sourceimpl Hash for StorageSlotChangedEvent
impl Hash for StorageSlotChangedEvent
Sourceimpl Ord for StorageSlotChangedEvent
impl Ord for StorageSlotChangedEvent
Sourcefn cmp(&self, other: &StorageSlotChangedEvent) -> Ordering
fn cmp(&self, other: &StorageSlotChangedEvent) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StorageSlotChangedEvent
impl PartialEq for StorageSlotChangedEvent
Sourcefn eq(&self, other: &StorageSlotChangedEvent) -> bool
fn eq(&self, other: &StorageSlotChangedEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for StorageSlotChangedEvent
impl PartialOrd for StorageSlotChangedEvent
Sourceimpl Serialize for StorageSlotChangedEvent
impl Serialize for StorageSlotChangedEvent
impl StructuralPartialEq for StorageSlotChangedEvent