pub struct ValidatorsCommittedForEraEvent {
pub era_index: u64,
}Fields
era_index: u64Trait Implementations
Sourceimpl Clone for ValidatorsCommittedForEraEvent
impl Clone for ValidatorsCommittedForEraEvent
Sourcefn clone(&self) -> ValidatorsCommittedForEraEvent
fn clone(&self) -> ValidatorsCommittedForEraEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Decode for ValidatorsCommittedForEraEvent
impl Decode for ValidatorsCommittedForEraEvent
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de> Deserialize<'de> for ValidatorsCommittedForEraEvent
impl<'de> Deserialize<'de> for ValidatorsCommittedForEraEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for ValidatorsCommittedForEraEvent
impl Encode for ValidatorsCommittedForEraEvent
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>(
&self,
f: __CodecUsingEncodedCallback,
) -> __CodecOutputReturn
fn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>( &self, f: __CodecUsingEncodedCallback, ) -> __CodecOutputReturn
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for ValidatorsCommittedForEraEvent
impl Eq for ValidatorsCommittedForEraEvent
Sourceimpl Ord for ValidatorsCommittedForEraEvent
impl Ord for ValidatorsCommittedForEraEvent
Sourcefn cmp(&self, other: &ValidatorsCommittedForEraEvent) -> Ordering
fn cmp(&self, other: &ValidatorsCommittedForEraEvent) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ValidatorsCommittedForEraEvent
impl PartialEq for ValidatorsCommittedForEraEvent
Sourcefn eq(&self, other: &ValidatorsCommittedForEraEvent) -> bool
fn eq(&self, other: &ValidatorsCommittedForEraEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ValidatorsCommittedForEraEvent
impl PartialOrd for ValidatorsCommittedForEraEvent
impl StructuralPartialEq for ValidatorsCommittedForEraEvent