pub enum MessageType {
Canonical,
Injected,
}Variants
Implementations
Sourceimpl MessageType
impl MessageType
Sourcepub const fn is_canonical(&self) -> bool
pub const fn is_canonical(&self) -> bool
Returns true if this value is of type Canonical. Returns false otherwise
Sourcepub const fn is_injected(&self) -> bool
pub const fn is_injected(&self) -> bool
Returns true if this value is of type Injected. Returns false otherwise