pub struct AggregatedPublicKey {
pub x: U256,
pub y: U256,
}Fields
x: U256y: U256Trait Implementations
Sourceimpl Clone for AggregatedPublicKey
impl Clone for AggregatedPublicKey
Sourcefn clone(&self) -> AggregatedPublicKey
fn clone(&self) -> AggregatedPublicKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AggregatedPublicKey
impl Debug for AggregatedPublicKey
Sourceimpl Decode for AggregatedPublicKey
impl Decode for AggregatedPublicKey
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Default for AggregatedPublicKey
impl Default for AggregatedPublicKey
Sourcefn default() -> AggregatedPublicKey
fn default() -> AggregatedPublicKey
Returns the “default value” for a type. Read more
Sourceimpl Encode for AggregatedPublicKey
impl Encode for AggregatedPublicKey
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for AggregatedPublicKey
impl Eq for AggregatedPublicKey
Sourceimpl PartialEq for AggregatedPublicKey
impl PartialEq for AggregatedPublicKey
Sourcefn eq(&self, other: &AggregatedPublicKey) -> bool
fn eq(&self, other: &AggregatedPublicKey) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AggregatedPublicKey