pub struct BatchCommitment {
pub block_hash: H256,
pub timestamp: u64,
pub previous_batch: Digest,
pub expiry: u8,
pub chain_commitment: Option<ChainCommitment>,
pub code_commitments: Vec<CodeCommitment>,
pub validators_commitment: Option<ValidatorsCommitment>,
pub rewards_commitment: Option<RewardsCommitment>,
}Expand description
Batch of different commitments that are created for a specific ethereum block.
Fields
block_hash: H256timestamp: u64Timestamp of ethereum block for which this batch has been created This timestamp is used to identify validator set to verify commitment (current or previous era)
previous_batch: DigestDigest of the previous committed batch. This is used to verify that the batch is committed in the correct order.
expiry: u8How long the batch is valid (in blocks since block_hash).
if 1 - then valid only in child block
if 2 - then valid in child and grandchild blocks
… etc.
chain_commitment: Option<ChainCommitment>code_commitments: Vec<CodeCommitment>validators_commitment: Option<ValidatorsCommitment>rewards_commitment: Option<RewardsCommitment>Trait Implementations
Sourceimpl Clone for BatchCommitment
impl Clone for BatchCommitment
Sourcefn clone(&self) -> BatchCommitment
fn clone(&self) -> BatchCommitment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BatchCommitment
impl Debug for BatchCommitment
Sourceimpl Decode for BatchCommitment
impl Decode for BatchCommitment
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Default for BatchCommitment
impl Default for BatchCommitment
Sourcefn default() -> BatchCommitment
fn default() -> BatchCommitment
Returns the “default value” for a type. Read more
Sourceimpl Encode for BatchCommitment
impl Encode for BatchCommitment
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for BatchCommitment
impl Eq for BatchCommitment
Sourceimpl PartialEq for BatchCommitment
impl PartialEq for BatchCommitment
Sourcefn eq(&self, other: &BatchCommitment) -> bool
fn eq(&self, other: &BatchCommitment) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BatchCommitment