pub struct ChainCommitment {
pub transitions: Vec<StateTransition>,
pub head: H256,
pub last_advanced_eth_block: H256,
}Expand description
Squashed chain commitment with state transitions, MB head, and the latest advanced Ethereum block hash, zero if no ethereum block has been advanced.
Fields
transitions: Vec<StateTransition>head: H256last_advanced_eth_block: H256Trait Implementations
Sourceimpl Clone for ChainCommitment
impl Clone for ChainCommitment
Sourcefn clone(&self) -> ChainCommitment
fn clone(&self) -> ChainCommitment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChainCommitment
impl Debug for ChainCommitment
Sourceimpl Decode for ChainCommitment
impl Decode for ChainCommitment
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for ChainCommitment
impl Encode for ChainCommitment
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for ChainCommitment
impl Eq for ChainCommitment
Sourceimpl PartialEq for ChainCommitment
impl PartialEq for ChainCommitment
Sourcefn eq(&self, other: &ChainCommitment) -> bool
fn eq(&self, other: &ChainCommitment) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ChainCommitment