pub struct ComputationSettings {
pub threshold: u64,
pub wvara_per_second: u128,
}Fields
threshold: u64wvara_per_second: u128Trait Implementations
Sourceimpl Clone for ComputationSettings
impl Clone for ComputationSettings
Sourcefn clone(&self) -> ComputationSettings
fn clone(&self) -> ComputationSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComputationSettings
impl Debug for ComputationSettings
Sourceimpl Decode for ComputationSettings
impl Decode for ComputationSettings
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Default for ComputationSettings
impl Default for ComputationSettings
Sourcefn default() -> ComputationSettings
fn default() -> ComputationSettings
Returns the “default value” for a type. Read more
Sourceimpl Encode for ComputationSettings
impl Encode for ComputationSettings
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for ComputationSettings
impl Eq for ComputationSettings
Sourceimpl PartialEq for ComputationSettings
impl PartialEq for ComputationSettings
Sourcefn eq(&self, other: &ComputationSettings) -> bool
fn eq(&self, other: &ComputationSettings) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ComputationSettings