pub struct StakerRewards {
pub vault: Address,
pub amount: U256,
}Fields
vault: Addressamount: U256Trait Implementations
Sourceimpl Clone for StakerRewards
impl Clone for StakerRewards
Sourcefn clone(&self) -> StakerRewards
fn clone(&self) -> StakerRewards
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StakerRewards
impl Debug for StakerRewards
Sourceimpl Decode for StakerRewards
impl Decode for StakerRewards
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Default for StakerRewards
impl Default for StakerRewards
Sourcefn default() -> StakerRewards
fn default() -> StakerRewards
Returns the “default value” for a type. Read more
Sourceimpl Encode for StakerRewards
impl Encode for StakerRewards
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for StakerRewards
impl Eq for StakerRewards
Sourceimpl PartialEq for StakerRewards
impl PartialEq for StakerRewards
Sourcefn eq(&self, other: &StakerRewards) -> bool
fn eq(&self, other: &StakerRewards) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for StakerRewards