pub struct StateTransition {
pub actor_id: ActorId,
pub new_state_hash: H256,
pub exited: bool,
pub inheritor: ActorId,
pub value_to_receive: u128,
pub value_to_receive_negative_sign: bool,
pub value_claims: Vec<ValueClaim>,
pub messages: Vec<Message>,
}Fields
actor_id: ActorIdnew_state_hash: H256exited: boolinheritor: ActorIdvalue_to_receive: u128We represent value_to_receive as u128 and bool because each non-zero byte costs 16 gas,
and each zero byte costs 4 gas (see https://evm.codes/about#gascosts).
Negative numbers will be stored like this:
$ cast
> -1 ether
Type: int256
Hex: 0xfffffffffffffffffffffffffffffffffffffffffffffffffffffff21f494c589c0000This is optimization on EVM side to reduce gas costs for storing and processing values.
value_to_receive_negative_sign: boolvalue_claims: Vec<ValueClaim>messages: Vec<Message>Trait Implementations
Sourceimpl Clone for StateTransition
impl Clone for StateTransition
Sourcefn clone(&self) -> StateTransition
fn clone(&self) -> StateTransition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StateTransition
impl Debug for StateTransition
Sourceimpl Decode for StateTransition
impl Decode for StateTransition
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Default for StateTransition
impl Default for StateTransition
Sourcefn default() -> StateTransition
fn default() -> StateTransition
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for StateTransition
impl<'de> Deserialize<'de> for StateTransition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for StateTransition
impl Encode for StateTransition
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for StateTransition
impl Eq for StateTransition
Sourceimpl Hash for StateTransition
impl Hash for StateTransition
Sourceimpl PartialEq for StateTransition
impl PartialEq for StateTransition
Sourcefn eq(&self, other: &StateTransition) -> bool
fn eq(&self, other: &StateTransition) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for StateTransition
impl Serialize for StateTransition
impl StructuralPartialEq for StateTransition
Sourceimpl ToDigest for StateTransition
impl ToDigest for StateTransition