pub struct ValidatorsCommitment {
pub has_aggregated_public_key: bool,
pub aggregated_public_key: AggregatedPublicKey,
pub verifiable_secret_sharing_commitment: Vec<u8>,
pub validators: ValidatorsVec,
pub era_index: u64,
}Fields
has_aggregated_public_key: boolDoes the batch have aggregated public key in validators commitment.
aggregated_public_key: AggregatedPublicKeyverifiable_secret_sharing_commitment: Vec<u8>validators: ValidatorsVecera_index: u64Trait Implementations
Sourceimpl Clone for ValidatorsCommitment
impl Clone for ValidatorsCommitment
Sourcefn clone(&self) -> ValidatorsCommitment
fn clone(&self) -> ValidatorsCommitment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidatorsCommitment
impl Debug for ValidatorsCommitment
Sourceimpl Decode for ValidatorsCommitment
impl Decode for ValidatorsCommitment
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for ValidatorsCommitment
impl Encode for ValidatorsCommitment
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for ValidatorsCommitment
impl Eq for ValidatorsCommitment
Sourceimpl PartialEq for ValidatorsCommitment
impl PartialEq for ValidatorsCommitment
Sourcefn eq(&self, other: &ValidatorsCommitment) -> bool
fn eq(&self, other: &ValidatorsCommitment) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ValidatorsCommitment