pub struct ValueClaim {
pub message_id: MessageId,
pub destination: ActorId,
pub value: u128,
}Fields
message_id: MessageIddestination: ActorIdvalue: u128Trait Implementations
Sourceimpl Clone for ValueClaim
impl Clone for ValueClaim
Sourcefn clone(&self) -> ValueClaim
fn clone(&self) -> ValueClaim
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValueClaim
impl Debug for ValueClaim
Sourceimpl Decode for ValueClaim
impl Decode for ValueClaim
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Default for ValueClaim
impl Default for ValueClaim
Sourcefn default() -> ValueClaim
fn default() -> ValueClaim
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ValueClaim
impl<'de> Deserialize<'de> for ValueClaim
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for ValueClaim
impl Encode for ValueClaim
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for ValueClaim
impl Eq for ValueClaim
Sourceimpl Hash for ValueClaim
impl Hash for ValueClaim
Sourceimpl PartialEq for ValueClaim
impl PartialEq for ValueClaim
Sourcefn eq(&self, other: &ValueClaim) -> bool
fn eq(&self, other: &ValueClaim) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ValueClaim
impl Serialize for ValueClaim
impl StructuralPartialEq for ValueClaim
Sourceimpl ToDigest for ValueClaim
impl ToDigest for ValueClaim