pub enum Receipt<P> {
Promise(P),
Purged(PurgedTransaction),
}Expand description
Receipt for InjectedTransaction.
This type generic over promise type in purpose to support both CompactPromise and Promise.
CompactPromise generic uses only for transport purposes. End user always receives the full version.
Important: Receipt<CompactPromise> and Receipt<Promise> have the same
digest. So it helps to reuses the producer’s signature to construct the full
version from compact.
Variants
Implementations
Sourceimpl<P> Receipt<P>
impl<P> Receipt<P>
Sourcepub fn unwrap_promise(self) -> P
pub fn unwrap_promise(self) -> P
Unwraps this value to the Receipt::Promise variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_purged(self) -> PurgedTransaction
pub fn unwrap_purged(self) -> PurgedTransaction
Unwraps this value to the Receipt::Purged variant.
Panics if this value is of any other type.
Sourceimpl<P: PromiseKind> Receipt<P>
impl<P: PromiseKind> Receipt<P>
pub fn tx_hash(&self) -> HashOf<InjectedTransaction>