#[repr(u8)]pub enum TransactionPurgedReason {
Outdated = 1,
UnknownReferenceBlock = 2,
NonZeroValue = 255,
}Expand description
Reason why transaction was not executed in chain.
Variants
Outdated = 1
The transaction references an outdated block and cannot be included.
UnknownReferenceBlock = 2
The transaction references a block that is not known locally.
NonZeroValue = 255
The transaction has a non-zero value, which is not supported yet.
Note: keep this variant at the end of the enum. The u8::MAX
discriminant intentionally leaves values 3..=254 available for
future purge reasons, including non-zero-value injected transactions.
Implementations
Sourceimpl TransactionPurgedReason
impl TransactionPurgedReason
pub fn variant_index(&self) -> u8