pub struct AddressedInjectedTransaction {
pub recipient: Address,
pub tx: SignedInjectedTransaction,
}Fields
recipient: AddressAddress of validator the transaction intended for
tx: SignedInjectedTransactionTrait Implementations
Sourceimpl Clone for AddressedInjectedTransaction
impl Clone for AddressedInjectedTransaction
Sourcefn clone(&self) -> AddressedInjectedTransaction
fn clone(&self) -> AddressedInjectedTransaction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddressedInjectedTransaction
impl Debug for AddressedInjectedTransaction
Sourceimpl Decode for AddressedInjectedTransaction
impl Decode for AddressedInjectedTransaction
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de> Deserialize<'de> for AddressedInjectedTransaction
impl<'de> Deserialize<'de> for AddressedInjectedTransaction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for AddressedInjectedTransaction
impl Encode for AddressedInjectedTransaction
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for AddressedInjectedTransaction
impl Eq for AddressedInjectedTransaction
Sourceimpl Hash for AddressedInjectedTransaction
impl Hash for AddressedInjectedTransaction
Sourceimpl PartialEq for AddressedInjectedTransaction
impl PartialEq for AddressedInjectedTransaction
Sourcefn eq(&self, other: &AddressedInjectedTransaction) -> bool
fn eq(&self, other: &AddressedInjectedTransaction) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AddressedInjectedTransaction