pub struct CompactPromise {
pub tx_hash: HashOf<InjectedTransaction>,
pub reply_hash: HashOf<ReplyInfo>,
}Expand description
The hashes of Promise parts.
Fields
tx_hash: HashOf<InjectedTransaction>reply_hash: HashOf<ReplyInfo>Trait Implementations
Sourceimpl Clone for CompactPromise
impl Clone for CompactPromise
Sourcefn clone(&self) -> CompactPromise
fn clone(&self) -> CompactPromise
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompactPromise
impl Debug for CompactPromise
Sourceimpl Decode for CompactPromise
impl Decode for CompactPromise
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for CompactPromise
impl Encode for CompactPromise
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for CompactPromise
impl Eq for CompactPromise
Sourceimpl PartialEq for CompactPromise
impl PartialEq for CompactPromise
Sourcefn eq(&self, other: &CompactPromise) -> bool
fn eq(&self, other: &CompactPromise) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PromiseKind for CompactPromise
impl PromiseKind for CompactPromise
fn tx_hash(&self) -> HashOf<InjectedTransaction>
impl StructuralPartialEq for CompactPromise