pub struct Promise {
pub tx_hash: HashOf<InjectedTransaction>,
pub reply: ReplyInfo,
}Expand description
Promise represents the guaranteed reply for InjectedTransaction.
Note: Validator must ensure the validity of the promise, because of it can be slashed for providing an invalid promise.
Fields
tx_hash: HashOf<InjectedTransaction>Hash of the injected transaction this reply corresponds to.
reply: ReplyInfoReply data for injected message.
Implementations
Sourceimpl Promise
impl Promise
Sourcepub fn reply_hash(&self) -> HashOf<ReplyInfo>
pub fn reply_hash(&self) -> HashOf<ReplyInfo>
Calculates the blake2b hash from promise’s reply.
Sourcepub fn to_compact(&self) -> CompactPromise
pub fn to_compact(&self) -> CompactPromise
Converts promise to its compact version.