pub struct PurgedTransaction {
pub tx_hash: HashOf<InjectedTransaction>,
pub reason: TransactionPurgedReason,
}Expand description
Represents the reason why InjectedTransaction was not included.
Fields
tx_hash: HashOf<InjectedTransaction>reason: TransactionPurgedReasonTrait Implementations
Sourceimpl Clone for PurgedTransaction
impl Clone for PurgedTransaction
Sourcefn clone(&self) -> PurgedTransaction
fn clone(&self) -> PurgedTransaction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PurgedTransaction
impl Debug for PurgedTransaction
Sourceimpl Decode for PurgedTransaction
impl Decode for PurgedTransaction
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de> Deserialize<'de> for PurgedTransaction
impl<'de> Deserialize<'de> for PurgedTransaction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for PurgedTransaction
impl Display for PurgedTransaction
Sourceimpl Encode for PurgedTransaction
impl Encode for PurgedTransaction
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for PurgedTransaction
impl Eq for PurgedTransaction
Sourceimpl PartialEq for PurgedTransaction
impl PartialEq for PurgedTransaction
Sourcefn eq(&self, other: &PurgedTransaction) -> bool
fn eq(&self, other: &PurgedTransaction) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PurgedTransaction
impl Serialize for PurgedTransaction
impl StructuralPartialEq for PurgedTransaction