pub struct ProcessQueuesLimits {
pub gas_allowance: u64,
}Expand description
Per-MB execution budget, carried on the wire.
Fields
gas_allowance: u64Trait Implementations
Sourceimpl Clone for ProcessQueuesLimits
impl Clone for ProcessQueuesLimits
Sourcefn clone(&self) -> ProcessQueuesLimits
fn clone(&self) -> ProcessQueuesLimits
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessQueuesLimits
impl Debug for ProcessQueuesLimits
Sourceimpl Decode for ProcessQueuesLimits
impl Decode for ProcessQueuesLimits
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Default for ProcessQueuesLimits
impl Default for ProcessQueuesLimits
Sourcefn default() -> ProcessQueuesLimits
fn default() -> ProcessQueuesLimits
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ProcessQueuesLimits
impl<'de> Deserialize<'de> for ProcessQueuesLimits
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for ProcessQueuesLimits
impl Encode for ProcessQueuesLimits
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>(
&self,
f: __CodecUsingEncodedCallback,
) -> __CodecOutputReturn
fn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>( &self, f: __CodecUsingEncodedCallback, ) -> __CodecOutputReturn
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for ProcessQueuesLimits
impl Eq for ProcessQueuesLimits
Sourceimpl PartialEq for ProcessQueuesLimits
impl PartialEq for ProcessQueuesLimits
Sourcefn eq(&self, other: &ProcessQueuesLimits) -> bool
fn eq(&self, other: &ProcessQueuesLimits) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProcessQueuesLimits
impl Serialize for ProcessQueuesLimits
impl StructuralPartialEq for ProcessQueuesLimits