pub enum SignedValidatorMessage {
RequestBatchValidation(SignedData<ValidatorRequest>),
ApproveBatch(SignedData<ValidatorReply>),
}Variants
RequestBatchValidation(SignedData<ValidatorRequest>)
ApproveBatch(SignedData<ValidatorReply>)
Implementations
Sourceimpl SignedValidatorMessage
impl SignedValidatorMessage
Sourcepub fn unwrap_request_batch_validation(self) -> SignedData<ValidatorRequest>
pub fn unwrap_request_batch_validation(self) -> SignedData<ValidatorRequest>
Unwraps this value to the SignedValidatorMessage::RequestBatchValidation variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_approve_batch(self) -> SignedData<ValidatorReply>
pub fn unwrap_approve_batch(self) -> SignedData<ValidatorReply>
Unwraps this value to the SignedValidatorMessage::ApproveBatch variant.
Panics if this value is of any other type.
Sourceimpl SignedValidatorMessage
impl SignedValidatorMessage
pub fn into_verified(self) -> VerifiedValidatorMessage