pub enum VerifiedValidatorMessage {
RequestBatchValidation(VerifiedData<ValidatorRequest>),
ApproveBatch(VerifiedData<ValidatorReply>),
}Variants
RequestBatchValidation(VerifiedData<ValidatorRequest>)
ApproveBatch(VerifiedData<ValidatorReply>)
Implementations
Sourceimpl VerifiedValidatorMessage
impl VerifiedValidatorMessage
Sourcepub fn unwrap_request_batch_validation(self) -> VerifiedData<ValidatorRequest>
pub fn unwrap_request_batch_validation(self) -> VerifiedData<ValidatorRequest>
Unwraps this value to the VerifiedValidatorMessage::RequestBatchValidation variant.
Panics if this value is of any other type.
Sourcepub fn unwrap_approve_batch(self) -> VerifiedData<ValidatorReply>
pub fn unwrap_approve_batch(self) -> VerifiedData<ValidatorReply>
Unwraps this value to the VerifiedValidatorMessage::ApproveBatch variant.
Panics if this value is of any other type.