pub struct CodeAndId { /* private fields */ }Implementations
Sourceimpl CodeAndId
impl CodeAndId
pub fn new(code: Vec<u8>) -> Self
pub fn code(&self) -> &[u8] ⓘ
pub fn code_id(&self) -> CodeId
Sourcepub fn from_unchecked(code_and_id: CodeAndIdUnchecked) -> Self
pub fn from_unchecked(code_and_id: CodeAndIdUnchecked) -> Self
Creates a new CodeAndId from an unchecked version, asserting that the code_id matches the generated one.
Panics
If the code_id does not match the generated one from the code, this function will panic.
pub fn into_unchecked(self) -> CodeAndIdUnchecked