pub struct ProtocolTimelines {
pub genesis_ts: u64,
pub era: NonZeroU64,
pub election: u64,
pub slot: NonZeroU64,
}Expand description
GearExe network timelines configuration. Parameters fetched the Router contract. This struct stores in the database, because of using in the multiple places.
Fields
genesis_ts: u64era: NonZeroU64election: u64The election duration in seconds before the end of an era when the next set of validators elected. (start of era)[ - - - - - - - - - - - - + - - - - ] (end of era) ^ election
slot: NonZeroU64The slot duration in seconds.
Implementations
Sourceimpl ProtocolTimelines
impl ProtocolTimelines
Sourcepub fn block_coordinator_at(
&self,
validators: &ValidatorsVec,
timestamp: u64,
) -> Option<Address>
pub fn block_coordinator_at( &self, validators: &ValidatorsVec, timestamp: u64, ) -> Option<Address>
Calculates the coordinator address for a given Ethereum block timestamp.
The coordinator is the validator picked once per Ethereum block to
aggregate finalized MBs into a BatchCommitment and submit it
on-chain. Block production itself is driven by Malachite — coordinator
election is independent.
Arguments
validators- A non-empty vector of validator addresses.timestamp- The timestamp for which to calculate the coordinator.
Returns None if timestamp is before genesis.
Sourcepub fn block_coordinator_index_at(
&self,
validators_amount: NonZeroUsize,
timestamp: u64,
) -> Option<usize>
pub fn block_coordinator_index_at( &self, validators_amount: NonZeroUsize, timestamp: u64, ) -> Option<usize>
Calculates the coordinator index for a given Ethereum block timestamp.
Arguments
validators_amount- The number of validators in the protocol.timestamp- The timestamp for which to calculate the coordinator index.
Returns None if timestamp is before genesis.
Sourceimpl ProtocolTimelines
impl ProtocolTimelines
Sourcepub fn era_from_ts(&self, ts: u64) -> Option<u64>
pub fn era_from_ts(&self, ts: u64) -> Option<u64>
Returns the era index for the given timestamp. Eras starts from 0.
Returns None if ts < genesis_ts
Sourcepub fn era_start_ts(&self, era_index: u64) -> Option<u64>
pub fn era_start_ts(&self, era_index: u64) -> Option<u64>
Returns the timestamp since which the given era started.
Returns None if overflows u64.
Sourcepub fn era_election_start_ts(&self, era_index: u64) -> Option<u64>
pub fn era_election_start_ts(&self, era_index: u64) -> Option<u64>
Returns the timestamp when election starts in the given era. NOTE: election starts for the next era validators.
Returns None if overflows u64.
Panics
Panics if era duration < election duration
Sourcepub fn slot_from_ts(&self, ts: u64) -> Option<u64>
pub fn slot_from_ts(&self, ts: u64) -> Option<u64>
Returns the slot index for the given timestamp. Slots starts from 0.
Returns None if ts < genesis_ts