Signature

Struct Signature 

pub struct Signature(/* private fields */);
A recoverable ECDSA signature.

Implementations

Source

impl Signature

pub fn create<T>( private_key: &PrivateKey, data: T, ) -> Result<Signature, SignerError>
where Digest: From<T>,

Create a recoverable signature for the provided data using the private key.

pub fn create_from_digest( private_key: &PrivateKey, digest: Digest, ) -> Result<Signature, SignerError>

Create a recoverable signature from a precomputed digest.

pub fn create_message<T>( private_key: &PrivateKey, data: T, ) -> Result<Signature, SignerError>
where Digest: From<T>,

Create a recoverable signature for the provided digest using the private key according to EIP-191.

pub fn recover<T>(&self, data: T) -> Result<PublicKey, SignerError>
where Digest: From<T>,

Recovers the public key which was used to create the signature for the signed data.

pub fn recover_from_digest( &self, digest: &Digest, ) -> Result<PublicKey, SignerError>

Recovers the public key using a precomputed digest.

pub fn recover_message<T>(&self, data: T) -> Result<PublicKey, SignerError>
where Digest: From<T>,

Recovers public key which was used to create the signature for the signed message according to EIP-191 standard.

pub fn verify<T>( &self, public_key: PublicKey, data: T, ) -> Result<(), SignerError>
where Digest: From<T>,

Verifies the signature using the public key and data.

pub fn verify_with_digest( &self, public_key: PublicKey, digest: &Digest, ) -> Result<(), SignerError>

Verifies the signature against a precomputed digest.

pub fn verify_message<T>( &self, public_key: PublicKey, data: T, ) -> Result<(), SignerError>
where Digest: From<T>,

Verifies message using Self::verify method according to EIP-191 standard.

pub fn validate<T>(&self, data: T) -> Result<PublicKey, SignerError>
where Digest: From<T>,

Signature validation with recovery.

pub fn validate_message<T>(&self, data: T) -> Result<PublicKey, SignerError>
where Digest: From<T>,

Signature validation: verify the signature with public key recovery from the signature of the message signed according to EIP-191 standard.

pub fn from_pre_eip155_bytes(bytes: [u8; 65]) -> Option<Signature>

Creates a signature from the bytes in the pre-EIP-155 format (V in {27, 28}).

pub fn into_pre_eip155_bytes(self) -> [u8; 65]

Convert signature into the pre-EIP-155 encoded bytes (V in {27, 28}).

pub fn as_raw_bytes(&self) -> [u8; 65]

Returns internal signature bytes with raw recovery id.

pub fn into_parts(self) -> (Signature<Secp256k1>, RecoveryId)

Return the inner signature and recovery id as k256 primitives.