SignedMessage

Struct SignedMessage 

pub struct SignedMessage<T> { /* private fields */ }
A signed according to EIP-191 message,that contains the data and its signature. Always valid after construction.

Implementations

Source

impl<T> SignedMessage<T>

pub fn data(&self) -> &T

pub fn signature(&self) -> &Signature

pub fn into_data(self) -> T

pub fn into_parts(self) -> (T, Signature)

pub fn into_parts_full(self) -> (T, Signature, Address)

pub fn address(&self) -> Address

Returns the address of the signer.

Source

impl<T> SignedMessage<T>
where Digest: for<'a> From<&'a T>,

Source

impl<T> SignedMessage<T>
where Digest: for<'a> From<&'a T>,

pub fn create( private_key: PrivateKey, data: T, ) -> Result<SignedMessage<T>, SignerError>

pub fn try_from_parts( data: T, signature: Signature, address: Address, ) -> Result<SignedMessage<T>, &'static str>

pub unsafe fn from_parts_unchecked( data: T, signature: Signature, address: Address, ) -> SignedMessage<T>

The unsafe constructor for SignedMessage.

It is useful to optimize the constructing signed wrappers for types with the same ToDigest implementation.

Safety

Safety only in cases when you are sure when hashes are equal.