pub struct SimpleBlockData {
pub hash: H256,
pub header: BlockHeader,
}Fields
hash: H256header: BlockHeaderTrait Implementations
Sourceimpl Clone for SimpleBlockData
impl Clone for SimpleBlockData
Sourcefn clone(&self) -> SimpleBlockData
fn clone(&self) -> SimpleBlockData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SimpleBlockData
Sourceimpl Debug for SimpleBlockData
impl Debug for SimpleBlockData
Sourceimpl Decode for SimpleBlockData
impl Decode for SimpleBlockData
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Default for SimpleBlockData
impl Default for SimpleBlockData
Sourcefn default() -> SimpleBlockData
fn default() -> SimpleBlockData
Returns the “default value” for a type. Read more
Sourceimpl Display for SimpleBlockData
impl Display for SimpleBlockData
Sourceimpl Encode for SimpleBlockData
impl Encode for SimpleBlockData
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for SimpleBlockData
impl Eq for SimpleBlockData
Sourceimpl PartialEq for SimpleBlockData
impl PartialEq for SimpleBlockData
Sourcefn eq(&self, other: &SimpleBlockData) -> bool
fn eq(&self, other: &SimpleBlockData) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SimpleBlockData