Receipt

Enum Receipt 

pub enum Receipt<P> {
    Promise(P),
    Purged(PurgedTransaction),
}
Receipt for InjectedTransaction.

This type generic over promise type in purpose to support both CompactPromise and Promise.

CompactPromise generic uses only for transport purposes. End user always receives the full version.

Important: Receipt<CompactPromise> and Receipt<Promise> have the same digest. So it helps to reuses the producer’s signature to construct the full version from compact.

Variants



Promise(P)



Purged(PurgedTransaction)

No promise, transaction wasn’t executed.

Implementations

Source

impl<P> Receipt<P>

pub const fn is_promise(&self) -> bool

Returns true if this value is of type Promise. Returns false otherwise

pub const fn is_purged(&self) -> bool

Returns true if this value is of type Purged. Returns false otherwise

Source

impl<P> Receipt<P>

pub fn unwrap_promise(self) -> P

Unwraps this value to the Receipt::Promise variant. Panics if this value is of any other type.

pub fn unwrap_purged(self) -> PurgedTransaction

Unwraps this value to the Receipt::Purged variant. Panics if this value is of any other type.

Source

impl<P: PromiseKind> Receipt<P>